@@ -14,12 +14,12 @@ use IO::Socket::SSL;
 use JSON;
 use Time::HiRes qw(time);
 use URI::Escape;
-use UUID::Tiny ':std';
+use UUID::Tiny;
 
 
 use vars qw($VERSION);
 
-$VERSION = '1.11';
+$VERSION = '1.12';
 
 our $DEBUG = 0;
 
@@ -484,7 +484,6 @@ sub invoke_payload {
     #   We will check to see if these need updates
     #
     my @should_have = ( @{ _unroll_ids( $store, \@out_ids ) } );
-
     my( @updates, %methods );
 
     #
@@ -530,11 +529,12 @@ sub invoke_payload {
         $methods{ $cls } = $server_root->_callable_methods;
     } 
     if( $session)  {
-
+        my %should_seen;
         #
         # check if existing are in the session
         #
         for my $should_have_id ( @should_have, keys %$ids2times ) {
+            next unless 0 == $should_seen{$should_have_id}++;
             # check if this needs an update
             my( $client_s, $client_ms )  = @{ $ids2times->{$should_have_id} || [] };
             my( $server_s, $server_ms )  = $store->_last_updated( $should_have_id );
@@ -672,7 +672,7 @@ sub _xform_out {
                 my( $extension ) = ( $orig_filename =~ /\.([^.\/]+)$/ );
 
                 # TODO - cleanup, maybe use File::Temp or something
-                my $newname = "/tmp/".create_uuid_as_string();
+                my $newname = "/tmp/".UUID::Tiny::create_uuid_as_string();
                 open (FILE, ">$newname");
                 while (read ($file, my $Buffer, 1024)) {
                     print FILE $Buffer;
@@ -787,7 +787,7 @@ sub __discover_methods {
     no strict 'refs';
     my @m = grep { $_ !~ /::/ } keys %{"${pkg}\::"};
     if( $pkg eq 'Yote::ServerObj' ) { #the base, presumably
-        return [ sort grep { $_ !~ /^(_|[gs]et_|(can|[sg]et|VERSION|AUTOLOAD|DESTROY|CARP_TRACE|BEGIN|isa|import|PKG2METHS|ISA)$)/ } @m ];
+        return [ sort grep { $_ !~ /^(_|[gs]et_|(can|[sg]et|VERSION|AUTOLOAD|DESTROY|CARP_TRACE|BEGIN|isa|import|PKG2METHS|ISA|add_to_|remove_from)$)/ } @m ];
     }
 
     my %hasm = map { $_ => 1 } @m;
@@ -799,7 +799,7 @@ sub __discover_methods {
     
     my $base_meths = __discover_methods( 'Yote::ServerObj' );
     my( %base ) = map { $_ => 1 } 'AUTOLOAD', @$base_meths;
-    $meths = [ sort grep { $_ !~ /^(_|[gs]et_|(can|[sg]et|VERSION|AUTOLOAD|DESTROY|BEGIN|isa|import|PKG2METHS|ISA)$)/ && ! $base{$_} } @m ];
+    $meths = [ sort grep { $_ !~ /^(_|[gs]et_|(can|[sg]et|VERSION|AUTOLOAD|DESTROY|BEGIN|isa|import|PKG2METHS|ISA|add_to_|remove_from)$)/ && ! $base{$_} } @m ];
     $Yote::ServerObj::PKG2METHS->{$pkg} = $meths;
     
     $meths;
@@ -985,6 +985,7 @@ sub fetch_root {
 sub init_root {
     my $self = shift;
     my $session = $self->{SESSION} || $self->_create_session;
+    $session->set__has_ids2times({});
     my $token = $session->get__token;
     return $self, $token;
 }
